@@ -20,7 +20,9 @@
 import argparse
 import logging
 import sys
+from getpass import getpass
 from typing import Optional
+from urllib.error import HTTPError
 
 from . import __version__
 from .api import get_latest_tag
@@ -29,8 +31,8 @@ from .api import get_latest_tag
 logger = logging.getLogger("tag_spy")
 
 
-def main() -> None:
-    """Define the console script entry point and thus the command line interface."""
+def parse_arguments():
+    """Parse all command line arguments."""
     parser = argparse.ArgumentParser(description="Find the latest Docker image tag.")
     parser.add_argument(
         "image",
@@ -43,12 +45,6 @@ def main() -> None:
         help="The first part of an image tag. So if your tags have the format "
         "'<image>:<base>_<date>_<commit>', you should supply the <base> here.",
     )
-    parser.add_argument(
-        "label",
-        metavar="LABEL",
-        help="The name of the label that contains the build timestamp, for example,"
-        " 'com.business.build.timestamp'.",
-    )
     parser.add_argument("--version", action="version", version=__version__)
     parser.add_argument(
         "--verbosity",
@@ -105,16 +101,29 @@ def main() -> None:
     if args.password_stdin:
         password: Optional[str] = sys.stdin.read().rstrip("\r\n")
     else:
-        password = input("Password:") if args.password else None
-    print(
-        get_latest_tag(
-            image=args.image,
-            base_tag=args.tag,
-            label=args.label,
-            authentication_url=args.authentication,
-            registry_url=args.registry,
-            service=args.service,
-            username=args.username,
-            password=password,
+        password = getpass() if args.password else None
+    args.password = password
+    return args
+
+
+def main() -> None:
+    """Define the console script entry point and thus the command line interface."""
+    args = parse_arguments()
+    try:
+        print(
+            get_latest_tag(
+                image=args.image,
+                base_tag=args.tag,
+                authentication_url=args.authentication,
+                registry_url=args.registry,
+                service=args.service,
+                username=args.username,
+                password=args.password,
+            )
         )
-    )
+    except HTTPError as error:
+        logger.debug("", exc_info=error)
+        logger.debug("%r", error.geturl())
+        logger.debug("%d %s", error.status, error.reason)  # type: ignore
+        logger.debug("HTTP Headers\n%s", error.info())
+        logger.critical(str(error))
